timeseria.time
==============

.. automodule:: timeseria.time

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      change_tz
      check_dt_consistency
      correct_dt_dst
      dt
      dt_from_s
      dt_from_str
      dt_to_str
      get_tz_offset_s
      now_dt
      now_s
      s_from_dt
      timezonize
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      dt_range
   
   

   
   
   



